<?php

namespace Litecms\NewsSetting\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\NewsSetting\Interfaces\NewsRepositoryInterface;

class NewsPublicController extends BaseController
{
    // use NewsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\News\Interfaces\NewsRepositoryInterface $news
     *
     * @return type
     */
    public function __construct(NewsRepositoryInterface $news)
    {
        $this->repository = $news;
        parent::__construct();
    }

    /**
     * Show news's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $news = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$news_setting::$news.names'))
            ->view('$news_setting::public.news.index')
            ->data(compact('$news'))
            ->output();
    }

    /**
     * Show news's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $news = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$news_setting::$news.names'))
            ->view('$news_setting::public.news.index')
            ->data(compact('$news'))
            ->output();
    }

    /**
     * Show news.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $news = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$news->name . trans('$news_setting::$news.name'))
            ->view('$news_setting::public.news.show')
            ->data(compact('$news'))
            ->output();
    }

}
